# eric7.MicroPython

Package implementing an interface to MicroPython devices like esp32.

### Packages

BluetoothDialogs | Package implementing Bluetooth related dialogs.
Devices | Package containing the device interface modules and device specific dialogs.
EthernetDialogs | Package implementing Ethernet related dialogs.
Tools | Package implementing some MicroPython related tools.
WifiDialogs | Package implementing WiFi related dialogs.

### Modules

AddEditDevicesDialog | Module implementing a dialog to add or edit data of unknown MicroPython devices.
BoardDataDialog | Module implementing a dialog to show information about a connected board.
ConnectionSelectionDialog | Module implementing a dialog to select the port to connect to and the type of the attached device.
ConvertToUF2Dialog | Module implementing a dialog to convert a .hex or .bin firmware file to .uf2.
IgnoredDevicesDialog | Module implementing a dialog to manage the list of ignored serial devices.
MicroPythonDeviceInterface | Module implementing some file system commands for MicroPython.
MicroPythonFileManager | Module implementing some file system commands for MicroPython.
MicroPythonFileManagerWidget | Module implementing a file manager for MicroPython devices.
MicroPythonFileSystemUtilities | Module implementing some file system utility functions.
MicroPythonGraphWidget | Module implementing the MicroPython graph widget.
MicroPythonProgressInfoDialog | Module implementing a dialog to show progress messages.
MicroPythonSerialPort | Module implementing a QSerialPort with additional functionality for MicroPython devices.
MicroPythonWidget | Module implementing the MicroPython REPL widget.
MipPackageDialog | Module implementing a dialog to enter the package data for 'mip'.
NtpParametersDialog | Module implementing a dialog to enter the NTP parameters.
ShowModulesDialog | Module implementing a dialog to show the available modules of all bundles.
UF2FlashDialog | Module implementing a dialog to flash any UF2 capable device.
UnknownDevicesDialog | Module implementing a dialog to manage the list of unknown devices.